@@ -827,6 +827,28 @@ class OpenEVSE:
         response = await self.process_request(url=url, method="get")  # noqa: E501
         return response
 
+    async def set_led_brightness(self, level: int) -> None:
+        """Set LED brightness level."""
+        if not self._version_check("4.1.0"):
+            _LOGGER.debug("Feature not supported for older firmware.")
+            raise UnsupportedFeature
+
+        url = f"{self.url}config"
+        data: dict[str, Any] = {}
+
+        data["led_brightness"] = level
+        _LOGGER.debug("Setting LED brightness to %s", level)
+        await self.process_request(url=url, method="post", data=data)  # noqa: E501
+
+    @property
+    def led_brightness(self) -> str:
+        """Return charger led_brightness."""
+        if not self._version_check("4.1.0"):
+            _LOGGER.debug("Feature not supported for older firmware.")
+            raise UnsupportedFeature
+        assert self._config is not None
+        return self._config["led_brightness"]
+
     @property
     def hostname(self) -> str:
         """Return charger hostname."""
@@ -1119,6 +1141,8 @@ class OpenEVSE:
         assert self._status is not None
         if "has_limit" in self._status:
             return self._status["has_limit"]
+        if "limit" in self._status:
+            return self._status["limit"]
         return None
 
     @property
@@ -1286,3 +1310,44 @@ class OpenEVSE:
         if self._status is not None and "mqtt_connected" in self._status:
             return self._status["mqtt_connected"]
         return False
+
+    @property
+    def emoncms_connected(self) -> bool | None:
+        """Return the status of the emoncms connection."""
+        if self._status is not None and "emoncms_connected" in self._status:
+            return self._status["emoncms_connected"]
+        return None
+
+    @property
+    def ocpp_connected(self) -> bool | None:
+        """Return the status of the ocpp connection."""
+        if self._status is not None and "ocpp_connected" in self._status:
+            return self._status["ocpp_connected"]
+        return None
+
+    @property
+    def uptime(self) -> int | None:
+        """Return the unit uptime."""
+        if self._status is not None and "uptime" in self._status:
+            return self._status["uptime"]
+        return None
+
+    @property
+    def freeram(self) -> int | None:
+        """Return the unit freeram."""
+        if self._status is not None and "freeram" in self._status:
+            return self._status["freeram"]
+        return None
+
+    # Safety counts
+    @property
+    def checks_count(self) -> dict | None:
+        """Return the saftey checks counts."""
+        attributes = ("gfcicount", "nogndcount", "stuckcount")
+        if self._status is not None and set(attributes).issubset(self._status.keys()):
+            counts = {}
+            counts["gfcicount"] = self._status["gfcicount"]
+            counts["nogndcount"] = self._status["nogndcount"]
+            counts["stuckcount"] = self._status["stuckcount"]
+            return counts
+        return None
